@@ -4,7 +4,7 @@ from urllib.request import Request
 from urllib.error import URLError
 from loguru import logger
 
-URL = 'http://www.chuangfeigu.com:58888/froapi/bot/chat'
+URL = 'http://api.chuangfeigu.com/froapi/bot/chat'
 
 
 class ChatError(Exception):
